#!/bin/sh
#
# Example mapping script
#
# Argument is IFACE
# Input is a series of lines each containing a triplet: ADDR PINGME LIFACE
# Output is the first LIFACE whose associated PINGME address can be
#   successfully pinged from IFACE temporarily configured with address ADDR,
#   if any
# Exit status is 0 if a LIFACE was printed, 1 otherwise
#

if [ `id -u` -ne 0 ] || [ "$1" = "" ]; then exit 1; fi

if [ -x /usr/bin/fping ]; then
	PING="/usr/bin/fping"
else
	PING="/bin/ping -c 2"
fi

IFACE="$1"

WHICH=""

while read ADDR PINGME LIFACE; do
	if [ "$WHICH" ]; then continue; fi

	#echo "  Trying to ping $PINGME from addr $ADDR ($LIFACE)" >&2

	ip addr add $ADDR dev $IFACE  >/dev/null 2>&1
	ip link set $IFACE up         >/dev/null 2>&1

	if $PING $PINGME >/dev/null 2>&1; then
		WHICH="$LIFACE"	
	fi
	ip link set $IFACE down       >/dev/null 2>&1
	ip addr del $ADDR dev $IFACE  >/dev/null 2>&1
done

if [ "$WHICH" ]; then
	echo $WHICH
	exit 0
fi
exit 1
